@@ -21,6 +21,13 @@ REBOOT_FILE = '/run/crond.reboot'
 
 SELF = os.path.basename(sys.argv[0])
 
+for pgm in ('/usr/sbin/sendmail', '/usr/lib/sendmail'):
+    if os.path.exists(pgm):
+        HAS_SENDMAIL = True
+        break
+else:
+    HAS_SENDMAIL = False
+
 class Persistent(object):
     yes, no, auto = range(3)
 
@@ -53,6 +60,15 @@ def expand_home_path(path, user):
             parts[i] = home + part[1:]
     return ':'.join(parts)
 
+def environment_string(env):
+    line = []
+    for k, v in env.items():
+        if ' ' in v:
+            line.append('"%s=%s"' % (k, v))
+        else:
+            line.append('%s=%s' % (k, v))
+    return ' '.join(line)
+
 def parse_crontab(filename, withuser=True, monotonic=False):
     basename = os.path.basename(filename)
     environment = { }
@@ -92,6 +108,10 @@ def parse_crontab(filename, withuser=True, monotonic=False):
                      environment['PATH'] = expand_home_path(value, basename)
                 elif envvar.group(1) == 'BATCH':
                      batch = (value.strip().lower() in ['yes','true','1'])
+                elif envvar.group(1) == 'MAILTO':
+                     environment[envvar.group(1)] = value
+                     if value and not HAS_SENDMAIL:
+                         log(4, 'a MTA is not installed, but MAILTO is set in %s' % filename)
                 else:
                      environment[envvar.group(1)] = value
                 continue
@@ -128,7 +148,7 @@ def parse_crontab(filename, withuser=True, monotonic=False):
                 jobid = ''.join(c for c in jobid if c in valid_chars)
 
                 yield {
-                        'e': ' '.join('"%s=%s"' % kv for kv in environment.items()),
+                        'e': environment_string(environment),
                         's': environment.get('SHELL','/bin/sh'),
                         'a': random_delay,
                         'l': line,
@@ -161,7 +181,7 @@ def parse_crontab(filename, withuser=True, monotonic=False):
                     user, command = (parts[1], ' '.join(parts[2:])) if withuser else (basename, ' '.join(parts[1:]))
 
                     yield {
-                            'e': ' '.join('"%s=%s"' % kv for kv in environment.items()),
+                            'e': environment_string(environment),
                             's': environment.get('SHELL','/bin/sh'),
                             'a': random_delay,
                             'l': line,
@@ -185,7 +205,7 @@ def parse_crontab(filename, withuser=True, monotonic=False):
                     user, command = (parts[5], ' '.join(parts[6:])) if withuser else (basename, ' '.join(parts[5:]))
 
                     yield {
-                            'e': ' '.join('"%s=%s"' % kv for kv in environment.items()),
+                            'e': environment_string(environment),
                             's': environment.get('SHELL','/bin/sh'),
                             'a': random_delay,
                             'l': line,
@@ -419,7 +439,12 @@ def generate_timer_unit(job, seq):
         f.write('RefuseManualStart=true\n')
         f.write('RefuseManualStop=true\n')
         f.write('SourcePath=%s\n' % job['f'])
-        if '"MAILTO="' not in job['e']: f.write('OnFailure=cron-failure@%i.service\n')
+        if '"MAILTO="' in job['e']:
+            pass # mails explicitely disabled
+        elif not HAS_SENDMAIL and '"MAILTO=' not in job['e']:
+            pass # mails automaticaly disabled
+        else:
+            f.write('OnFailure=cron-failure@%i.service\n')
         if job['u'] != 'root' or job['f'] == '@statedir@/root':
             f.write('Requires=systemd-user-sessions.service\n')
             if home: f.write('RequiresMountsFor=%s\n' % home)
